# goflow
This repository is all about simulating flow driven pruning in biological flow networks. / CURRENTLY UNDER CONSTRUCTION

##  Introduction
This module 'goflow' is the final of a series of pyton packages encompassing a set of class and method implementations for a kirchhoff network datatype, in order to to calculate flow/flux on lumped parameter model circuits and their corresponding adaptation. The flow/flux objects are embedded in the kirchhoff networks, and can be altered independently from the underlying graph structure. This is meant for fast(er) and efficient computation and dependends on the packages 'kirchhoff','hailhydro'.
##  Installation
pip install goflow
##  Usage

CURRENTLY UNDER CONSTRUCTION

##  Requirements
``` pandas ```,``` networkx ```, ``` numpy ```, ``` scipy ```, ``` kirchhoff ```, ``` hailhydro ```
##  Gallery

## Acknowledgement
```goflow``` written by Felix Kramer
